@@ -1,9 +1,11 @@
 package Imager::Font::Type1;
 use strict;
 use Imager::Color;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 @ISA = qw(Imager::Font);
 
+$VERSION = "1.011";
+
 *_first = \&Imager::Font::_first;
 
 my $t1aa;
@@ -109,7 +111,8 @@ sub has_chars {
     $Imager::ERRSTR = "No string supplied to \$font->has_chars()";
     return;
   }
-  return Imager::i_t1_has_chars($self->{id}, $hsh{string}, $hsh{'utf8'} || 0);
+  return Imager::i_t1_has_chars($self->{id}, $hsh{string}, 
+				_first($hsh{'utf8'}, $self->{utf8}, 0));
 }
 
 sub utf8 {
@@ -127,7 +130,7 @@ sub glyph_names {
 
   my $string = $input{string};
   defined $string
-    or return Imager->_seterror("no string parameter passed to glyph_names");
+    or return Imager->_set_error("no string parameter passed to glyph_names");
   my $utf8 = _first($input{utf8} || 0);
 
   Imager::i_t1_glyph_name($self->{id}, $string, $utf8);
@@ -145,7 +148,7 @@ __END__
 =head1 DESCRIPTION
 
 Imager::Font creates a Imager::Font::Type1 object when asked to create
-a font object based on a .pfb file.
+a font object based on a C<.pfb> file.
 
 See Imager::Font to see how to use this type.
 
@@ -157,22 +160,26 @@ can re-enable that by calling Imager::init() with the C<t1log> option:
 
   Imager::init(t1log=>1);
 
+This must be called before creating any fonts.
+
 Currently specific to Imager::Font::Type1, you can use the following
 flags when drawing text or calculating a bounding box:
 
+=for stopwords overline strikethrough
+
 =over
 
-=item underline
+=item *
 
-Draw the text with an underline.
+C<underline> - Draw the text with an underline.
 
-=item overline
+=item *
 
-Draw the text with an overline.
+C<overline> - Draw the text with an overline.
 
-=item strikethrough
+=item *
 
-Draw the text with a strikethrough.
+C<strikethrough> - Draw the text with a strikethrough.
 
 =back
 
